#
# spec file for package libqca2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with botan
%if 0%{?suse_version} > 1320
# Enable gcrypt plugin on TW
%bcond_without gcrypt
# Disable PKCS11 on TW, conflicts with older openssl
%bcond_with pkcs11
%else
%bcond_with gcrypt
%bcond_without pkcs11
%endif
%bcond_without nss

Name:           libqca2
Version:        2.1.3
Release:        3.2
Summary:        Qt Cryptographic Architecture 2
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            https://userbase.kde.org/QCA
Source:         http://download.kde.org/stable/qca/%{version}/src/qca-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM (Needed for 0002 to apply)
Patch1:         0001-Revert-tlsunittest-disable-some-ciphers.patch
# PATCH-FIX-UPSTREAM (Variant of 0001, but for master)
Patch2:         0002-Disable-missed-openssl-cipher-suites.patch
# PATCH-FIX-UPSTREAM
Patch3:         0003-Add-support-for-OpenSSL-1.1.0.patch
BuildRequires:  ca-certificates
BuildRequires:  cmake >= 2.8.12
BuildRequires:  cyrus-sasl-devel
BuildRequires:  gpg2
BuildRequires:  libdrm-devel
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(QtCore) >= 4.7
BuildRequires:  pkgconfig(openssl)
Requires:       gpg2 >= 2.0.0
%requires_eq    libqt4
%if %{with botan}
BuildRequires:  pkgconfig(botan-1.10)
%endif
%if %{with gcrypt}
BuildRequires:  libgcrypt-devel >= 1.7
%endif
%if %{with nss}
BuildRequires:  pkgconfig(nss)
%endif
%if %{with pkcs11}
BuildRequires:  pkgconfig(libpkcs11-helper-1)
%endif

%description
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%package devel
Summary:        Development files for the Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libqt4-devel

%description devel
This package provides a generic Qt cryptographic architecture,
including a library and a plugin for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES and AES.

%package plugin-cyrus-sasl
Summary:        Cyrus SASL plugin for the Qt Cryptographic Architecture 2
Group:          System/Libraries
Requires:       %{name} = %{version}

%description plugin-cyrus-sasl
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%package plugin-gcrypt
Summary:        Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description plugin-gcrypt
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%package plugin-botan
Summary:        Botan plugin for the Qt Cryptographic Architecture 2
Group:          System/Libraries
Requires:       %{name} = %{version}
Provides:       %{name}:%{_libdir}/qt4/plugins/crypto/libqca-botan.so

%description plugin-botan
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%package plugin-nss
Summary:        NSS plugin for the Qt Cryptographic Architecture 2
Group:          System/Libraries
Requires:       %{name} = %{version}

%description plugin-nss
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%package plugin-pkcs11
Summary:        PKCS#11 support for the Qt Cryptographic Architecture 2
Group:          System/Libraries
Requires:       %{name} = %{version}

%description plugin-pkcs11
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%prep
%setup -q -n qca-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
# TODO: When needed switch to Qt5 build
%cmake \
    -DQCA_PLUGINS_INSTALL_DIR=%{_libdir}/qt4/plugins/ \
    -DQCA_FEATURE_INSTALL_DIR=%{_datadir}/qt4/mkspecs/features/ \
    -DQT4_BUILD=ON \
    -DWITH_cyrus-sasl_PLUGIN=ON \
%if %{with gcrypt}
    -DWITH_gcrypt_PLUGIN=ON \
%endif
    -DWITH_gnupg_PLUGIN=ON \
    -DWITH_logger_PLUGIN=ON \
%if %{with botan}
    -DWITH_botan_PLUGIN=ON \
%endif
%if %{with nss}
    -DWITH_nss_PLUGIN=ON \
%endif
%if %{with pkcs11}
    -DWITH_pkcs11_PLUGIN=ON \
%endif
    -DWITH_ossl_PLUGIN=ON
make %{?_smp_mflags}

%install
%cmake_install

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING TODO
%{_bindir}/mozcerts
%{_libdir}/libqca.so.*
%dir %{_libdir}/qt4/plugins/crypto
%{_libdir}/qt4/plugins/crypto/libqca-logger.so
%{_libdir}/qt4/plugins/crypto/libqca-softstore.so
%{_libdir}/qt4/plugins/crypto/libqca-ossl.so
%{_libdir}/qt4/plugins/crypto/libqca-gnupg.so

%files devel
%defattr(-,root,root)
%{_bindir}/qcatool
%{_includedir}/QtCrypto
%{_datadir}/qt4/mkspecs/features/crypto.prf
%{_mandir}/man1/qcatool.1.*
%{_libdir}/libqca.so
%{_libdir}/pkgconfig/qca2.pc
%{_libdir}/cmake/Qca/

%files plugin-cyrus-sasl
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-cyrus-sasl.so

%if %{with gcrypt}
%files plugin-gcrypt
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-gcrypt.so
%endif

%if %{with botan}
%files plugin-botan
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-botan.so
%endif

%if %{with nss}
%files plugin-nss
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-nss.so
%endif

%if %{with pkcs11}
%files plugin-pkcs11
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-pkcs11.so
%endif

%changelog
* Wed Dec 27 2017 jengelh@inai.de
- Remove idempotent %%if..%%endif guards.
  Diversify subpackage descriptions.
* Wed Dec 20 2017 fabian@ritter-vogt.de
- Add patches to support OpenSSL 1.1.0:
  * 0001-Revert-tlsunittest-disable-some-ciphers.patch
  * 0002-Disable-missed-openssl-cipher-suites.patch
  * 0003-Add-support-for-OpenSSL-1.1.0.patch
* Fri Dec 15 2017 fabian@ritter-vogt.de
- BuildIgnore libopenssl-1_1_0-devel to avoid conflict
* Thu Oct 19 2017 meissner@suse.com
- buildignore openssl-1_0_0 to avoid conflicts during the
  openssl 1.1 effort.
* Sun Oct  1 2017 wbauer@tmo.at
- updated to version 2.1.3
  * no changelog provided
- update Url
* Thu Aug 24 2017 fvogt@suse.com
- Force building against openSSL 1.0 (boo#1055310)
- Disable PKCS11 on TW to avoid openssl conflicts
* Thu Aug 25 2016 fabian@ritter-vogt.de
- Add new plugin-gcrypt subpackage
* Thu Dec 17 2015 tchvatal@suse.com
- Pass all required switches to cmake to ensure it builds properly
- Install manpage to correct location
* Thu Dec 17 2015 tchvatal@suse.com
- Switch to bcond_with/without usage instead of 0/1 defines
* Sun Dec  6 2015 mailaender@opensuse.org
- update to version 2.1.1 (now part of KDE)
- use system root certificates
* Mon Nov 23 2015 mailaender@opensuse.org
- updated to version 2.1.0 (plugins now included)
  - Ported to Qt5 (Qt4 also supported)
  - New building system. CMake instead of qmake
  - Added CTR symetric cipher support to qca core
  - Added no padding encryption algorithm to qca core
  - qcatool2 renamed to qcatool
  - fixed crash in qcatool when only options provided on command line without any commands
  - Use plugins installation path as hard-coded runtime plugins search path
  - Added new functiion pluginPaths
  - Added functions to get runtime QCA version
  - Fixed 'no watch file' warnings in FileWatch
  - Added EME_PKCS1v15_SSL Encryption Algorithm
  - New implementation of SafeTimer to prevent crashes
  - Updated certificates for unittests
  - RSA Keys are permutable, can encrypt with private and decrypt with public
  - Add unloadProvider() function for symmetry with insertProvider()
  - Overloaded "makeKey" to derive a password depending on a time factor
  - Remove pointer to deinit() routine from QCoreApplication at deinitialization
  - Fix a couple of crashes where all plugins might not be available
  - Fix operating on keys with unrelated expired subkeys
  - Fixed timers in Synchronizer class
  - Dropped randomunittest
  - Fixed many unittests
  - qca-gnupg: internal refactoring
  - qca-gnupg: try both gpg and gpg2 to find gnupg executable
  - qca-gnupg: fixed some encodings problem
  - qca-ossl: no DSA_* dl groups in FIPS specification
  - qca-ossl: added missed signatures to CRLContext
  - qca-ossl: fixed certs time zone
  - qca-nss: fixed KeyLenght for Cipher
  - qca-botan: fixed getting result size for ciphers
- removed deprecated patches:
  - fix-qt-check.diff
  - r928413.diff
  - disable-insecure-ssl.diff
  - qca-2.0.3-gcc47.patch
  - detect_ssl2_available.diff
  - qca-no-ssl-internals.patch
- enabled plugin-nss
- spec file cleanup
* Sat Apr 19 2014 crrodriguez@opensuse.org
- qca-no-ssl-internals.patch + spec file: Never use
  the ssl library internals directly, instead use the proper
  API accessors.
* Wed Apr 16 2014 hrvoje.senjan@gmail.com
- Added detect_ssl2_available.diff: fix build with no-ssl2 in
  openssl lib
* Fri Oct 11 2013 crrodriguez@opensuse.org
- build with -DOPENSSL_LOAD_CONF so QCA respects and uses
  the system's openSSL configuration.
* Thu Mar 15 2012 aj@suse.de
- Fix build with gcc 4.7.
* Sun Mar 11 2012 crrodriguez@opensuse.org
- Build respecting RPM_OPT_FLAGS, ugly hack to fix all
  * .pro files ensued.
- Build with visibility-inlines-hidden
* Thu Jun 23 2011 dmueller@suse.de
- update to 2.0.3:
  - Bugfix release, forward and backward compatible with 2.0.x
  - Fix compilation when using Qt/Windows SDK
* Thu Jun 23 2011 dmueller@suse.de
- remove dependency on botan now that it got broken
* Mon Apr 19 2010 dmueller@suse.de
- fix build when MD2 support is disabled (as default in openSSL 1.0.x)
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Sat Jul 11 2009 beineri@opensuse.org
- fix build on Factory by including upstream commit 864423:
  remove whirlpool hash usage. the algorithm is missing on at least
  0.9.8g/i/k, even though there is an OBJ_whirlpool definition
* Wed Jul  8 2009 dmueller@suse.de
- readd qt dependency
* Fri Jul  3 2009 prusnak@suse.cz
- updated to 2.0.2
  * Bugfix release, forward and backward compatible with 2.0.x
  * Fix compatibility with Qt 4.5 when QCA::Initializer appears before QApp
  * Don't convert to secure memory when Hash::update(QByteArray) is used
* Sun May  3 2009 dmueller@suse.de
- qt plugins need *exactly* the same Qt version
* Thu Feb 19 2009 dmueller@suse.de
- fix build with gcc 4.4
- fix build for older distros
- fix baselibs configuration
* Wed Feb 11 2009 ro@suse.de
- added libqca2 to baselibs.conf (required by plugins)
* Tue Feb  3 2009 dmueller@suse.de
- fix qt version check (bnc#471444)
* Thu Jan 22 2009 dmueller@suse.de
- add baselibs.conf
* Thu Aug 28 2008 wstephenson@suse.de
- update to 2.0.1
  * Bugfix release
  * the pkgconfig file is always qca2.pc, even in debug mode
  * Certificates containing wildcards are now matched properly
  * DirWatch/FileWatch now work
  * Keystore writes now work
  * Don't delete objects in their event handler (prevents Qt 4.4 warnings)
  * Fix potential hang with TLS in server mode
- improve packaging
* Mon Jul  7 2008 dmueller@suse.de
- update qca providers to latest beta release (bnc#379500)
* Sat Oct 20 2007 dmueller@suse.de
- only move the pkgconfig file for lib64 archs
* Thu Oct 18 2007 dmueller@suse.de
- build fix
* Thu Oct 18 2007 dmueller@suse.de
- improve packaging
* Wed Oct 17 2007 dmueller@suse.de
- update to 2.0.0 final:
  - Rewritten for Qt 4
  - MAC algorithms
  - DSA
  - Diffie-Hellman
  - Secure random
  - Secure memory
  - Extensive X.509 API, supporting chains, crls, and validation
  - Smart cards and other key storage
  - OpenPGP
  - Cryptographic Message Syntax (for S/MIME)
  - probably more
* Tue Aug 28 2007 dmueller@suse.de
- update to 2.0.0-test1:
  * finalized API
* Mon Aug  6 2007 aj@suse.de
- Botan-devel -> libbotan-devel
* Fri Aug  3 2007 dmueller@suse.de
- update to svn695914
- build plugins modular
- add nss, gcrypt, gnupg and cyrus-sasl plugins
* Mon Jun 25 2007 dmueller@suse.de
- update to svn revision680219
* Thu May 31 2007 dmueller@suse.de
- update to svn670229 to fix compilation with gcc 4.3
* Mon Apr 23 2007 dmueller@suse.de
- build against system Botan
* Thu Apr 19 2007 dmueller@suse.de
- spec file cleanup
* Sat Apr 14 2007 dmueller@suse.de
- fix build
* Wed Apr 11 2007 dmueller@suse.de
- fix -devel package requires
* Thu Apr  5 2007 dmueller@suse.de
- remove examples from devel package
* Tue Jan 23 2007 dmueller@suse.de
- fix build on lib64 platforms
* Mon Jan 22 2007 dmueller@suse.de
- Initial package (SVN r626102)
